.. _loghandler:

Loghandler
==========

Log-handlers output log entries to somewhere. If you want to send your logs somewhere configure one of
these. There are log-handlers to show log entries on the console. Send them to a syslog process, server,
etc.

.. toctree::

    console
    file
    syslog
